@@ -7,6 +7,20 @@ from amocrm.config_reader.read_config import get_config_list
 from s3.client import Client as S3Client
 
 
+def check_keys_compatibility(dict_to_update, dict_additional):
+    """
+    Check for keys need to run
+    :param dict_to_update:
+    :param dict_additional:
+    :return: True if values in dicts are compatible
+    """
+    keys_exists = [key for key in dict_to_update if key in dict_additional]
+    for key in keys_exists:
+        if dict_to_update[key] != dict_additional[key]:
+            return False
+    return True
+
+
 def run_from_config(
         file_dir,
         **args_additional
@@ -20,7 +34,10 @@ def run_from_config(
     config_list = get_config_list(file_dir)
     for config_entity in config_list:
         extract_params, db_params_list = config_entity
-        extract_params.update(args_additional)
+        if check_keys_compatibility(extract_params, args_additional):
+            extract_params.update(args_additional)
+        else:
+            continue
         AmocrmRunner(**extract_params).run()
         for db_params in db_params_list:
             db_params.update(args_additional)
@@ -28,7 +45,10 @@ def run_from_config(
             if "parser" in db_params:
                 parse_params = db_params.copy()
                 parse_params["action"] = "parse"
-                parse_params.update(args_additional)
+                if check_keys_compatibility(parse_params, args_additional):
+                    parse_params.update(args_additional)
+                else:
+                    continue
                 AmocrmRunner(**parse_params).run()
 
         AmocrmRunner(**extract_params).clean_s3()
